<?php
/**
*
* common [Ukrainian]
*
* @package language
* @version $Id: common.php 9046 2008-11-02 16:19:11Z acydburn $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
  	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
//
// Some characters you may want to copy&paste:
// ’ » “ ” …
//

$lang = array_merge($lang, array(
	'TRANSLATION_INFO'	=> 'Український переклад &copy 2005-2011 <a class="copyright" target="_blank" href="http://phpbb.com.ua/">Українська підтримка phpBB</a>',
	'DIRECTION'	=> 'ltr',
	'DATE_FORMAT'	=> '|d M Y|',
	'USER_LANG'	=> 'uk',

	'1_DAY'	=> '1 день',
	'1_MONTH'	=> '1 місяць',
	'1_YEAR'	=> '1 рік',
	'2_WEEKS'	=> '2 тижні',
	'3_MONTHS'	=> '3 місяці',
	'6_MONTHS'	=> '6 місяців',
	'7_DAYS'	=> '7 днів',

	'ACCOUNT_ALREADY_ACTIVATED'	=> 'Ваш обліковий запис вже активовано',
	'ACCOUNT_DEACTIVATED'	=> 'Ваш обліковий запис було деактивовано вручну і лише адміністратор може активувати його.',
	'ACCOUNT_NOT_ACTIVATED'	=> 'Ваш обліковий запис ще неактивовано',
	'ACP'	=> 'Панель адміністратора',
	'ACTIVE'	=> 'активний',
	'ACTIVE_ERROR'	=> 'Ви ввели неактивне ім\'я користувача. Якщо у вас виникли проблеми з активацією облікового запису, зв\'яжіться, будь-ласка, з адміністратором форуму.',
	'ADMINISTRATOR'	=> 'Адміністратор',
	'ADMINISTRATORS'	=> 'Адміністратори',
	'AGE'	=> 'Вік',
	'AIM'	=> 'AIM',
	'ALLOWED'	=> 'Дозволено',
	'ALL_FILES'	=> 'Усі файли',
	'ALL_FORUMS'	=> 'Усі форуми',
	'ALL_MESSAGES'	=> 'Усі повідомлення',
	'ALL_POSTS'	=> 'Усі повідомлення',
	'ALL_TIMES'	=> 'Часовий пояс %1$s %2$s',
	'ALL_TOPICS'	=> 'Усі теми',
	'AND'	=> 'і',
	'ARE_WATCHING_FORUM'	=> 'Ви підписались отримувати інформацію про надходження нових повідомлень в цей форум.',
	'ARE_WATCHING_TOPIC'	=> 'Ви підписались отримувати інформацію про надходження нових повідомлень в цю тему.',
	'ASCENDING'	=> 'за зростанням',
	'ATTACHMENTS'	=> 'Приєднані файли',
	'ATTACHED_IMAGE_NOT_IMAGE'	=> 'Файл зображень, який ви намагались приєднати невірний.',
	'AUTHOR'	=> 'Автор',
	'AUTH_NO_PROFILE_CREATED'	=> 'Не вдалось створити профіль користувача',
	'AVATAR_DISALLOWED_CONTENT'      => 'Завантаження файлу на сервер було відхилено через те, що даний файл було ідентифіковано як можливий спосіб атаки.',
	'AVATAR_DISALLOWED_EXTENSION'	=> 'Неможливо відобразити цей файл, оскільки розширення <strong>%s</strong> заборонене.',
	'AVATAR_EMPTY_REMOTE_DATA'	=> 'Неможливо завантажити аватар на сервер, файл невірного типу або пошкоджений.',
	'AVATAR_EMPTY_FILEUPLOAD'	=> 'Завантажений файл аватару порожній.',
	'AVATAR_INVALID_FILENAME'	=> 'Невірне ім\'я файлу %s.',
	'AVATAR_NOT_UPLOADED'	=> 'Не вдалось завантажити аватар.',
	'AVATAR_NO_SIZE'	=> 'Неможливо визначити ширину або висоту віддаленого аватару, будь-ласка, введіть їх вручну.',
	'AVATAR_PARTIAL_UPLOAD'	=> 'Файл було завантажено неповністю',
	'AVATAR_PHP_SIZE_NA'	=> 'Розмір файлу аватара надто великий.<br />Максимально допустимий розмір, визначений PHP в php.ini, неможливо визначити.',
	'AVATAR_PHP_SIZE_OVERRUN'	=> 'Розмір файлу аватара надто великий. Максимально допустимий розмір %1$d %2$s.<br />Обмеження розміру встановлене в php.ini і не може бути перевищеним.',
	'AVATAR_URL_INVALID'	=> 'Вказана вами адреса невірна.',
	'AVATAR_URL_NOT_FOUND'	=> 'Вказаний файл не знайдено.',
	'AVATAR_WRONG_FILESIZE'	=> 'Розмір аватару повинен бути від 0 до %1d %2s.',
	'AVATAR_WRONG_SIZE'	=> ' Ваш аватар має ширину %5$d точок та висоту %6$d точок. Аватар повинен бути як мінімум %1$d точок завширшки та %2$d точок заввишки, але не більше %3$d точок завширшки та %4$d точок заввишки.',

	'BACK_TO_TOP'	=> 'Догори',
	'BACK_TO_PREV'	=> 'Повернутись на попередню сторінку',
	'BAN_TRIGGERED_BY_EMAIL'	=> 'Доступ до форуму заборонено для вашої адреси електронної пошти.',
	'BAN_TRIGGERED_BY_IP'	=> 'Доступ до форуму заборонено для вашої ip-адреси.',
	'BAN_TRIGGERED_BY_USER'	=> 'Доступ до форуму заборонено для вашого облікового запису.',
	'BBCODE_GUIDE'	=> 'Про BBCode',
	'BCC'	=> 'BCC',
	'BIRTHDAYS'	=> 'Дні народження',
	'BOARD_BAN_PERM'	=> 'Вам заборонено доступ до форуму <strong>permanently</strong>.<br /><br />Зв\'яжіться, будь-ласка, з %2$sадміністратором форуму%3$s для отримання додаткової інформації.',
	'BOARD_BAN_REASON'	=> 'Причина: <strong>%s</strong>',
	'BOARD_BAN_TIME'	=> 'Вам заборонено доступ до форуму до <strong>%1$s</strong>.<br /><br />Зв\'яжіться, будь-ласка, з %2$sадміністратором форуму%3$s для отримання додаткової інформації.',
	'BOARD_DISABLE'	=> 'Вибачте, форум тимчасово недоступний.',
	'BOARD_DISABLED'	=> 'Форум наразі вимкнено.',
	'BOARD_UNAVAILABLE'	=> 'Вибачте, форум тимчасово недоступний, спробуйте зайти через кілька хвилин.',
	'BROWSING_FORUM'      => 'Користувачі, які зараз переглядають цей форум: %1$s',
	'BROWSING_FORUM_GUEST'	=> 'Зараз переглядають цей форум: %1$s і %2$d гість',
	'BROWSING_FORUM_GUESTS'	=> 'Зараз переглядають цей форум: %1$s і %2$d гостей',
	'BYTES'	=> 'байт',

	'CANCEL'	=> 'Скасувати',
	'CHANGE'	=> 'Змінити',
	'CHANGE_FONT_SIZE'	=> 'Змінити розмір шрифту',
	'CHANGING_PREFERENCES'	=> 'Змінює налаштування форуму',
	'CHANGING_PROFILE'	=> 'Змінює налаштування профілю',
	'CLICK_VIEW_PRIVMSG'	=> '%sПерейти до вхідних%s',
	'COLLAPSE_VIEW'	=> 'Згорнутий вигляд',
	'CLOSE_WINDOW'	=> 'Закрити вікно',
	'COLOUR_SWATCH'	=> 'Палітра',
	'COMMA_SEPARATOR'	=> ', ',
	'CONFIRM'	=> 'Підтвердження',
	'CONFIRM_CODE'	=> 'Код підтвердження',
	'CONFIRM_CODE_EXPLAIN'	=> 'Введіть код точно так, як на зображенні. Регістр букв немає значення.',
	'CONFIRM_CODE_WRONG'	=> 'Введений вами код підтвердження невірний.',
	'CONFIRM_OPERATION'	=> 'Ви впевнені що бажаєте виконати цю операцію?',
	'CONGRATULATIONS'	=> 'Вітаємо',
	'CONNECTION_FAILED'	=> 'Помилка з\'єднання.',
	'CONNECTION_SUCCESS'	=> 'З\'єднання успішне!',
	'COOKIES_DELETED'	=> 'Усі файли cookies, встановлені форумом, успішно видалено.',
	'CURRENT_TIME'	=> 'Сьогодні: %s',

	'DAY'	=> 'День',
	'DAYS'	=> 'Дні',
	'DELETE'	=> 'Видалити',
	'DELETE_ALL'	=> 'Видалити всі',
	'DELETE_COOKIES'	=> 'Видалити встановлені форумом файли cookie',
	'DELETE_MARKED'	=> 'Видалити позначені',
	'DELETE_POST'	=> 'Видалити повідомлення',
	'DELIMITER'	=> 'Розділювач',
	'DESCENDING'	=> 'за спаданням',
	'DISABLED'	=> 'Вимкнено',
	'DISPLAY'	=> 'Показувати',
	'DISPLAY_GUESTS'	=> 'Показати гостей',
	'DISPLAY_MESSAGES'	=> 'Показувати теми за',
	'DISPLAY_POSTS'	=> 'Показувати повідомлення за',
	'DISPLAY_TOPICS'	=> 'Показувати теми за',
	'DOWNLOADED'	=> 'Кількість завантажень',
	'DOWNLOADING_FILE'	=> 'Завантаження файлу',
	'DOWNLOAD_COUNT'	=> 'Завантажено %d раз',
	'DOWNLOAD_COUNTS'	=> 'Завантажено %d разів',
	'DOWNLOAD_COUNT_NONE'	=> 'Ще не завантажувалось',

	'VIEWED_COUNT'	=> 'Переглянуто %d раз',
	'VIEWED_COUNTS'	=> 'Переглянуто %d разів',
	'VIEWED_COUNT_NONE'	=> 'Ще не переглядалось',

	'EDIT_POST'	=> 'Редагувати повідомлення',
	'EMAIL'	=> 'E-mail', // Short form for EMAIL_ADDRESS
	'EMAIL_ADDRESS'	=> 'Адреса e-mail',
	'EMAIL_SMTP_ERROR_RESPONSE'	=> 'Помилка при відправленні e-mail в <strong>стрічці %1$s</strong>. Відповідь сервера: %2$s',
	'EMPTY_SUBJECT'	=> 'При створенні нової теми необхідно вказати заголовок.',
	'EMPTY_MESSAGE_SUBJECT'	=> 'Ви повинні вказати тему при створенні нового повідомлення.',
	'ENABLED'	=> 'Увімкнено',
	'ENCLOSURE'	=> 'Обмежувач',
	'ENTER_USERNAME'					=> 'Введіть ім\'я користувача',

	'ERR_JAB_AUTH'						=> 'Не вдалось авторизуватись на сервері Jabber.',
	'ERR_JAB_CONNECT'					=> 'Не вдалось під\'єднатись до сервера Jabber.',
	'ERR_CHANGING_DIRECTORY'	=> 'Невдалось змінити директорію.',
	'ERR_CONNECTING_SERVER'	=> 'Помилка підключення до сервера.',
	'ERR_UNABLE_TO_LOGIN'	=> 'Вказані вами ім\'я користувача або пароль невірні.',
  'ERR_UNWATCHING'               => 'Сталася помилка при спробі скасувати підписку.',
  'ERR_WATCHING'                  => 'Сталася помилка при спробі оформити підписку.',
	'ERR_WRONG_PATH_TO_PHPBB'	=> 'Заданий шлях до phpBB невірний.',
	'EXPAND_VIEW'	=> 'Розгорнутий вигляд',
	'EXTENSION'	=> 'Розширення',
	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'Розширення <strong>%s</strong> було заборонено, приєднаний файл більше недоступний',
	'FAQ'	=> 'Допомога',
	'FAQ_EXPLAIN'	=> 'Часті питання',
	'FILENAME'	=> 'Ім\'я файлу',
	'FILESIZE'	=> 'Розмір файлу',
	'FILEDATE'	=> 'Дата файлу',
	'FILE_COMMENT'	=> 'Опис файлу',
	'FILE_NOT_FOUND'	=> 'Файл, який ви запитували, не знайдено',
	'FIND_USERNAME'	=> 'Знайти учасника',
	'FOLDER'	=> 'Директорія',
	'FORGOT_PASS'	=> 'Я забув свій пароль',
	'FORM_INVALID'	=> 'Відправлена вами форма невірна. Спробуйте відправити ще раз.',
	'FORUM'	=> 'Форум',
	'FORUMS'	=> 'Форуми',
	'FORUMS_MARKED'	=> 'Обрані вами форуми позначено прочитаними',
	'FORUM_CAT'	=> 'Категорія',
	'FORUM_INDEX'	=> 'Список форумів',
	'FORUM_LINK'	=> 'Посилання на форум',
	'FORUM_LOCATION'	=> 'Місцезнаходження на форумі',
	'FORUM_LOCKED'	=> 'Форум закритий',
	'FORUM_RULES'	=> 'Правила форуму',
	'FORUM_RULES_LINK'	=> 'Натисніть тут для перегляду правил форуму',
	'FROM'	=> 'з',
	'FSOCK_DISABLED'	=> 'Ця операція не може бути виконана, тому що функцію <var>fsockopen</var> вимкнено або сервер недоступний.',
	'FSOCK_TIMEOUT'			=> 'Виникла помилка під час читання потоку даних з мережі.',

	'FTP_FSOCK_HOST'	=> 'FTP-сервер',
	'FTP_FSOCK_HOST_EXPLAIN'	=> 'FTP-сервер для з\'єднання з вашим сайтом.',
	'FTP_FSOCK_PASSWORD'	=> 'Пароль FTP',
	'FTP_FSOCK_PASSWORD_EXPLAIN'	=> 'Пароль для входу на FTP-сервер.',
	'FTP_FSOCK_PORT'	=> 'Порт FTP',
	'FTP_FSOCK_PORT_EXPLAIN'	=> 'Порт для з\'єднання з FTP-сервером.',
	'FTP_FSOCK_ROOT_PATH'	=> 'Шлях до phpBB',
	'FTP_FSOCK_ROOT_PATH_EXPLAIN'	=> 'Шлях від кореневої директорії до директорії з phpBB.',
	'FTP_FSOCK_TIMEOUT'	=> 'Таймаут FTP',
	'FTP_FSOCK_TIMEOUT_EXPLAIN'	=> 'Час в секундах, впродовж якого система буде чекати на відповідь FTP-сервера.',
	'FTP_FSOCK_USERNAME'	=> 'Ім\'я користувача FTP',
	'FTP_FSOCK_USERNAME_EXPLAIN'	=> 'Ім\'я користувача, яке використовується для з\'єднання з FTP-сервером.',
	'FTP_HOST'	=> 'FTP-сервер',
	'FTP_HOST_EXPLAIN'	=> 'FTP-сервер для з\'єднання з вашим сайтом.',
	'FTP_PASSWORD'	=> 'Пароль FTP',
	'FTP_PASSWORD_EXPLAIN'	=> 'Пароль для входу на FTP-сервер.',
	'FTP_PORT'	=> 'Порт FTP',
	'FTP_PORT_EXPLAIN'	=> 'Порт для з\'єднання з FTP-сервером.',
	'FTP_ROOT_PATH'	=> 'Шлях до phpBB',
	'FTP_ROOT_PATH_EXPLAIN'	=> 'Шлях від кореневої директорії до директорії з phpBB.',
	'FTP_TIMEOUT'	=> 'Таймаут FTP',
	'FTP_TIMEOUT_EXPLAIN'	=> 'Час в секундах, впродовж якого система буде чекати на відповідь FTP-сервера.',
	'FTP_USERNAME'	=> 'Ім\'я користувача FTP',
	'FTP_USERNAME_EXPLAIN'	=> 'Ім\'я користувача, яке використовується для з\'єднання з FTP-сервером.',
	'GENERAL_ERROR'	=> 'Критична помилка',
	'GB'                  => 'Гб',
	'GIB'                  => 'Гб',
	'GO'	=> 'Вперед',
	'GOTO_PAGE'	=> 'На сторінку',
	'GROUP'	=> 'Група',
	'GROUPS'	=> 'Групи',
	'GROUP_ERR_TYPE'	=> 'Вибрано невідповідний тип групи.',
	'GROUP_ERR_USERNAME'	=> 'Не вказане ім\'я групи.',
	'GROUP_ERR_USER_LONG'	=> 'Назва групи не може перевищувати 60 символів. Задана вами назва групи надто довга.',
	'GUEST'	=> 'Гість',
	'GUEST_USERS_ONLINE'	=> 'Зараз онлайн %d гостей',
	'GUEST_USERS_TOTAL'	=> '%d гостей',
	'GUEST_USERS_ZERO_ONLINE'	=> 'Зараз онлайн 0 гостей',
	'GUEST_USERS_ZERO_TOTAL'	=> '0 гостей',
	'GUEST_USER_ONLINE'	=> 'Зараз %d гість онлайн',
	'GUEST_USER_TOTAL'	=> '%d гість',
	'G_ADMINISTRATORS'	=> 'Адміністратори',
	'G_BOTS'	=> 'Пошукові боти',
	'G_GUESTS'	=> 'Гості',
	'G_REGISTERED'	=> 'Зареєстровані користувачі',
	'G_REGISTERED_COPPA'	=> 'Зареєстровані COPPA користувачі',
	'G_GLOBAL_MODERATORS'	=> 'Супермодератори',
	'G_NEWLY_REGISTERED'		=> 'Нові користувачі',
	'HIDDEN_USERS_ONLINE'	=> '%d прихованих користувачів',
	'HIDDEN_USERS_TOTAL'	=> '%d прихованих',
	'HIDDEN_USERS_TOTAL_AND'      => '%d прихованих і ',
	'HIDDEN_USERS_ZERO_ONLINE'	=> '0 прихованих користувачів',
	'HIDDEN_USERS_ZERO_TOTAL'	=> '0 прихованих',
	'HIDDEN_USERS_ZERO_TOTAL_AND'   => '0 прихованих і ',
	'HIDDEN_USER_ONLINE'	=> '%d прихований',
	'HIDDEN_USER_TOTAL'	=> '%d прихованих',
	'HIDDEN_USER_TOTAL_AND'         => '%d прихованих і ',
	'HIDE_GUESTS'	=> 'Приховати гостей',
	'HIDE_ME'	=> 'Приховати моє перебування на форумі цього разу',
	'HOURS'	=> 'Години',
	'HOME'	=> 'Головна',
	'ICQ'	=> 'ICQ',
	'ICQ_STATUS'	=> 'Статус ICQ',
	'IF'	=> 'якщо',
	'IMAGE'	=> 'Зображення',
	'IMAGE_FILETYPE_INVALID'	=> 'Тип файлу зображення %d для MIME-типу %s не підтримується.',
	'IMAGE_FILETYPE_MISMATCH'	=> 'Тип файлу зображення не співпадає: очікуване розширення %1$s замість отриманого %2$s.',
	'IN'	=> 'в',
	'INDEX'	=> 'Головна',
	'INFORMATION'	=> 'Інформація',
	'INTERESTS'	=> 'Інтереси',
	'INVALID_DIGEST_CHALLENGE'	=> 'Невірний запит автентифікації',
	'INVALID_EMAIL_LOG'	=> '<strong>%s</strong> можливо введена невірна адреса електронної пошти?',
	'IP'	=> 'IP',
	'IP_BLACKLISTED'	=> 'Ваш IP %1$s заблоковано, тому що його внесено до чорного списку. Для додаткової інформації дивіться <a href="%2$s">%2$s</a>.',
	'JABBER'	=> 'Jabber',
	'JOINED'	=> 'З нами з',
	'JUMP_PAGE'	=> 'Введіть номер сторінки, на яку бажаєте перейти',
	'JUMP_TO'	=> 'Вперед',
	'JUMP_TO_PAGE'	=> 'Перейти на сторінку',
	'KB'	=> 'Кб',
	'KIB'               => 'Кб',
	'LAST_POST'	=> 'Останнє повідомлення',
	'LAST_UPDATED'	=> 'Востаннє оновлено',
	'LAST_VISIT'	=> 'Останнє відвідування',
	'LDAP_NO_LDAP_EXTENSION'	=> 'Розширення LDAP недоступне',
	'LDAP_NO_SERVER_CONNECTION'	=> 'Неможливо з\'єднатись з сервером LDAP.',
  'LDAP_SEARCH_FAILED'            => 'Виникла помилка при пошуку в директорії LDAP.',
	'LEGEND'	=> 'Легенда',
	'LOCATION'	=> 'Звідки',
	'LOCK_POST'	=> 'Заблокувати повідомлення',
	'LOCK_POST_EXPLAIN'	=> 'Заборонити редагування',
	'LOCK_TOPIC'	=> 'Закрити тему',
	'LOGIN'	=> 'Вхід',
	'LOGIN_CHECK_PM'	=> 'Увійти, щоб переглянути приватні повідомлення',
	'LOGIN_CONFIRMATION'	=> 'Підтвердження входу',
	'LOGIN_CONFIRM_EXPLAIN'	=> 'Для запобігання підбору паролю до вашого облікового запису вам необхідно ввести код підтвердження після максимальної кількості невдалих спроб логування. Код знаходиться внизу на зображенні. Якщо ви з якихось причин не бачите код на зображенні, зв\'яжіться, будь-ласка, з %sАдміністраторами форуму%s.', // unused
	'LOGIN_ERROR_ATTEMPTS'	=> 'Ви перевищили максимальну кількість спроб логування. Крім вашого імені користувача і паролю тепер вам необхідно вирішити нижчеподане завдання CAPTCHA.',
	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Apache не зміг вас автентифікувати.',
	'LOGIN_ERROR_PASSWORD'	=> 'Ви ввели невірний пароль. Будь-ласка, перевірте ваш пароль і повторіть вашу спробу. Якщо у вас все одно є проблеми з входом, будь-ласка,  зв\'яжіться з %sАдміністраторами форуму%s.',
	'LOGIN_ERROR_PASSWORD_CONVERT'	=> 'Не вдалось переконвертувати ваш пароль під час оновлення ПЗ форуму. Будь-ласка, %sвідішліть запит на новий пароль%s. Якщо у вас все одно є проблеми з входом, будь-ласка, зв\'яжіться з %sАдміністраторами форуму%s.',
	'LOGIN_ERROR_USERNAME'	=> 'Ви ввели невірне ім\'я користувача. Будь-ласка, перевірте ваше ім\'я користувача і повторіть вашу спробу. Якщо у вас все одно є проблеми з входом, будь-ласка,  зв\'яжіться з %sАдміністраторами форуму%s.',
	'LOGIN_FORUM'	=> 'Для перегляду чи розміщення нових повідомлень в цьому форумі вам потрібно ввести пароль.',
	'LOGIN_INFO'	=> 'Для входу на форум ви повинні бути зареєстровані. Реєстрація займає декілька секунд але надає вам більш широкі можливості. Адміністратор може надати додаткові привілеї зареєстрованим користувачам. Перед тим, як увійти, будь-ласка, переконайтесь що ви погоджуєтесь з правилами та політиками, які прийняті на форумі. Пам\'ятайте, що ваше перебування на форумі означає вашу згоду з усіма правилами.',
	'LOGIN_VIEWFORUM'	=> 'Для перегляду цього форуму ви повинні бути зареєстровані та залоговані.',
	'LOGIN_EXPLAIN_EDIT'	=> 'Для редагування повідомлень цього форуму ви повинні бути зареєстровані та залоговані.',
	'LOGIN_EXPLAIN_VIEWONLINE'	=> 'Для перегляду списку онлайн-користувачів  ви повинні бути зареєстровані та залоговані.',
	'LOGOUT'	=> 'Вихід',
	'LOGOUT_USER'	=> 'Вихід [ %s ]',
	'LOG_ME_IN'	=> 'Запам\'ятати мене з цього комп\'ютера',
   
	'MARK'	=> 'Позначити',
	'MARK_ALL'	=> 'Позначити усі',
	'MARK_FORUMS_READ'	=> 'Позначити всі форуми прочитаними',
  'MARK_SUBFORUMS_READ'	=> 'Позначити всі підфоруми прочитаними',
	'MB'	=> 'Мб',
	'MIB'               => 'Мб',
	'MCP'	=> 'Панель модератора',
	'MEMBERLIST'	=> 'Учасники',
	'MEMBERLIST_EXPLAIN'	=> 'Переглянути повний список учасників',
	'MERGE'	=> 'Об\'єднати',
	'MERGE_TOPIC'	=> 'Об\'єднати тему',
	'MESSAGE'	=> 'Повідомлення',
	'MESSAGES'	=> 'Повідомлень',
	'MESSAGE_BODY'	=> 'Текст повідомлення',
	'MINUTES'	=> 'Хвилин',
	'MODERATE'	=> 'Модерувати',
	'MODERATOR'	=> 'Модератор',
	'MODERATORS'	=> 'Модератори',
	'MONTH'	=> 'Місяць',
	'MOVE'	=> 'Перемістити',
	'MSNM'	=> 'MSNM/WLM',
	'NA'	=> 'Н/Д',
	'NEWEST_USER'	=> 'Останній зареєстрований учасник: <strong>%s</strong>',
	'NEW_MESSAGE'	=> 'Нове повідомлення',
	'NEW_MESSAGES'	=> 'Нові повідомлення',
	'NEW_PM'	=> '<strong>%d</strong> нове повідомлення',
	'NEW_PMS'	=> '<strong>%d</strong> нових повідомлень',
	'NEW_POST'	=> 'Нове повідомлення',	// Not used anymore
	'NEW_POSTS'	=> 'Нові повідомлення',	// Not used anymore
	'NEXT'	=> 'Далі',
	'NEVER'	=> 'Ніколи',
	'NO'	=> 'Ні',
	'NOT_ALLOWED_MANAGE_GROUP'	=> 'Ви не можете керувати цією групою.',
	'NOT_AUTHORISED'	=> 'Ви не маєте доступу в цю частину форуму.',
	'NOT_WATCHING_FORUM'	=> 'Ви більше не слідкуєте за повідомленнями в цьому форумі.',
	'NOT_WATCHING_TOPIC'	=> 'Ви більше не слідкуєте за цією темою.',
	'NOTIFY_ADMIN'	=> 'Будь-ласка, повідомте адміністратора форуму або вебмайстра.',
	'NOTIFY_ADMIN_EMAIL'	=> 'Будь-ласка повідомте адміністратора форуму або вебмайстра: <a href="mailto:%1$s">%1$s</a>',
	'NO_ACCESS_ATTACHMENT'	=> 'Вам заборонено доступ до цього файлу.',
	'NO_ACTION'	=> 'Дія невизначена.',
	'NO_ADMINISTRATORS'	=> 'Адміністратори відсутні.',
	'NO_AUTH_ADMIN'	=> 'Доступ до Панелі адміністратора заборонено, оскільки ви не маєте прав доступу адміністратора.',
	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Ви не можете повторно авторизуватись як інший користувач.',
	'NO_AUTH_OPERATION'	=> 'Ви не маєте необхідних прав для завершення цієї операції.',
	'NO_CONNECT_TO_SMTP_HOST'	=> 'Неможливо з\'єднатись з SMTP-сервером : %1$s : %2$s',
	'NO_BIRTHDAYS'	=> 'Сьогодні немає днів народження.',
	'NO_EMAIL_MESSAGE'	=> 'Текст e-mail повідомлення відсутній.',
	'NO_EMAIL_RESPONSE_CODE'	=> 'Неможливо отримати відповідь від поштового сервера.',
	'NO_EMAIL_SUBJECT'	=> 'Тема e-mail повідомлення відсутня.',
	'NO_FORUM'	=> 'Форум, який ви обрали не існує.',
	'NO_FORUMS'	=> 'Цей форум немає розділів.',
	'NO_GROUP'	=> 'Такої групи не існує.',
	'NO_GROUP_MEMBERS'	=> 'В цій групі поки немає жодного учасника.',
	'NO_IPS_DEFINED'	=> 'Не задано IP-адресу або ім\'я хосту.',
	'NO_MEMBERS'	=> 'Не знайдено жодного учасника за заданими критеріями.',
	'NO_MESSAGES'	=> 'Немає повідомлень',
	'NO_MODE'	=> 'Режим не заданий.',
	'NO_MODERATORS'	=> 'Модератори відсутні',
	'NO_NEW_MESSAGES'	=> 'Немає нових повідомлень',
	'NO_NEW_PM'	=> '<strong>0</strong> нових повідомлень',
	'NO_NEW_POSTS'	=> 'Немає нових повідомлень',	// Not used anymore
	'NO_ONLINE_USERS'	=> 'Немає зареєстрованих користувачів',
	'NO_POSTS'	=> 'Немає повідомлень',
	'NO_POSTS_TIME_FRAME'	=> 'За обраний період часу немає повідомлень.',
  'NO_FEED_ENABLED' => 'Канали новин недоступні на цьому форумі.',
  'NO_FEED' => 'Заданий канал новин недоступний.',
	'NO_SUBJECT'	=> 'Тему не задано',
	'NO_SUCH_SEARCH_MODULE'	=> 'За заданими критеріями нічого не знайдено.',
	'NO_SUPPORTED_AUTH_METHODS'	=> 'Метод автентифікації не підтримується.',
	'NO_TOPIC'	=> 'Задана тема не існує.',
	'NO_TOPIC_FORUM'	=> 'Тема або форум більше не існує.',
	'NO_TOPICS'	=> 'В цьому форумі немає повідомлень.',
	'NO_TOPICS_TIME_FRAME'	=> 'Форум не містить тем за даний період часу.',
	'NO_UNREAD_PM'	=> '<strong>0</strong> непрочитаних повідомлень',
	'NO_UPLOAD_FORM_FOUND'	=> 'Завантаження файлу на сервер ініційоване, але доступний для завантаження файл не знайдено.',
	'NO_UNREAD_POSTS'         => 'Немає непрочитаних повідомлень',
	'NO_USER'	=> 'Заданого користувача не знайдено.',
	'NO_USERS'	=> 'Заданих користувачів не знайдено.',
	'NO_USER_SPECIFIED'	=> 'Не задане ім\'я користувача.',


	   // Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
   	'NUM_POSTS_IN_QUEUE'      => array(
     	 0         => 'Немає повідомлень у черзі',      // 0
     	 1         => '1 повідомлення у черзі',      // 1
      	2         => '%d повідомлень у черзі',      // 2+
   ),
	'OCCUPATION'	=> 'Рід занять',
	'OFFLINE'	=> 'Офлайн',
	'ONLINE'	=> 'Онлайн',
	'ONLINE_BUDDIES'	=> 'Друзі',
	'ONLINE_USERS_TOTAL'	=> 'Всього онлайн <strong>%d</strong> користувачів :: ',
	'ONLINE_USERS_ZERO_TOTAL'	=> 'Всього онлайн <strong>0</strong> користувачів :: ',
	'ONLINE_USER_TOTAL'	=> 'Всього онлайн <strong>%d</strong> користувач :: ',
	'OPTIONS'	=> 'Налаштування',
	'PAGE_OF'	=> 'Сторінка <strong>%1$d</strong> з <strong>%2$d</strong>',
	'PASSWORD'	=> 'Пароль',
  'PIXEL'		=> 'пікс.',
	'PLAY_QUICKTIME_FILE'	=> 'Програти файл QuickTime',
	'PM'	=> 'ПП',
  'PM_REPORTED'         => 'Натисніть для перегляду звіту',
	'POSTING_MESSAGE'	=> 'Розміщення повідомлення в %s',
	'POSTING_PRIVATE_MESSAGE'	=> 'Пише приватне повідомлення',
	'POST'	=> 'Повідомлення',
	'POST_ANNOUNCEMENT'	=> 'Оголошення',
	'POST_STICKY'	=> 'Прикріплено',
	'POSTED'	=> 'Додано',
	'POSTED_IN_FORUM'	=> 'в',
	'POSTED_ON_DATE'	=> 'від ',
	'POSTS'	=> 'Повідомлення',
	'POSTS_UNAPPROVED'	=> 'Як мінімум одне повідомлення в цій темі не було перевірено.',
	'POST_BY_AUTHOR'	=> '',
	'POST_BY_FOE'	=> 'Автором цього повідомлення є <strong>%1$s</strong>, який внесений до вашого чорного списку. %2$sПоказати це повідомлення%3$s.',
	'POST_DAY'	=> '%.2f повідомлень за день',
	'POST_DETAILS'	=> 'Інформація про повідомлення',
	'POST_NEW_TOPIC'	=> 'Створити нову тему',
	'POST_PCT'	=> '%.2f%% від усіх повідомлень',
	'POST_PCT_ACTIVE'	=> '%.2f%% від усіх повідомлень',
	'POST_PCT_ACTIVE_OWN'	=> '%.2f%% від ваших повідомлень',
	'POST_REPLY'	=> 'Відповісти',
	'POST_REPORTED'	=> 'Переглянути скаргу',
	'POST_SUBJECT'	=> 'Тема повідомлення',
	'POST_TIME'	=> 'Час розміщення',
	'POST_UNAPPROVED'	=> 'Це повідомлення очікує на перевірку',
	'PREVIEW'	=> 'Попередній перегляд',
	'PREVIOUS'	=> 'Поперед.',
	'PRIVACY'	=> 'Заява про конфіденційність',
	'PRIVATE_MESSAGE'	=> 'Приватне повідомлення',
	'PRIVATE_MESSAGES'	=> 'Приватні повідомлення',
	'PRIVATE_MESSAGING'	=> 'Приватні повідомлення',
	'PROFILE'	=> 'Панель керування',
	'READING_FORUM'	=> 'Переглядає повідомлення в %s',
	'READING_GLOBAL_ANNOUNCE'	=> 'Читає загальне оголошення',
	'READING_TOPIC'	=> 'Переглядає тему в %s',
	'READ_PROFILE'	=> 'Профіль',
	'REASON'	=> 'Причина',
	'RECORD_ONLINE_USERS'	=> 'Рекорд відвідуваності <strong>(%1$s одночасно)</strong> відбувся %2$s',
	'REDIRECT'	=> 'Перейти',
	'REDIRECTS'	=> 'Переходів по посиланню',
	'REGISTER'	=> 'Реєстрація',
	'REGISTERED_USERS'	=> 'Зареєстровані учасники:',
	'REG_USERS_ONLINE'	=> '%d зареєстрованих користувачів і ',
	'REG_USERS_TOTAL'	=> '%d зареєстрованих, ',
	'REG_USERS_TOTAL_AND'      => '%d зареєстрованих і ',
	'REG_USERS_ZERO_ONLINE'	=> '0 зареєстрованих користувачів і ',
	'REG_USERS_ZERO_TOTAL'	=> '0 зареєстрованих, ',
	'REG_USERS_ZERO_TOTAL_AND'   => '0 зареєстрованих і ',
	'REG_USER_ONLINE'	=> '%d зареєстрований користувач і ',
	'REG_USER_TOTAL'	=> '%d зареєстрованих, ',
	'REG_USER_TOTAL_AND'      => '%d зареєстрованих і ',
	'REMOVE'	=> 'Видалити',
	'REMOVE_INSTALL'	=> 'Будь-ласка видаліть, перемістіть або перейменуйте директорію install. Якщо ця директорія буде присутня, доступною буде лише Панель Адміністратора.',
	'REPLIES'	=> 'Відповіді',
	'REPLY_WITH_QUOTE'	=> 'Відповісти з цитатою',
	'REPLYING_GLOBAL_ANNOUNCE'	=> 'Пише відповідь на загальне оголошення',
	'REPLYING_MESSAGE'	=> 'Пише відповідь в форумі %s',
	'REPORT_BY'	=> 'Від',
	'REPORT_POST'	=> 'Поскаржитись на це повідомлення',
	'REPORTING_POST'	=> 'Відсилає скаргу на дане повідомлення',
	'RESEND_ACTIVATION'	=> 'Повторно вислати лист активації',
	'RESET'	=> 'Скидання',
	'RESTORE_PERMISSIONS'	=> 'Відновити права доступу',
	'RETURN_INDEX'	=> '%sПовернутись на головну%s',
	'RETURN_FORUM'	=> '%sПовернутися на форум%s',
	'RETURN_PAGE'	=> '%sНа попередню сторінку%s',
	'RETURN_TOPIC'	=> '%sПовернутись до теми%s',
	'RETURN_TO'	=> 'Повернутись до',
  'FEED' => 'Канал',
  'FEED_NEWS' => 'Новини',
  'FEED_TOPICS_ACTIVE'		=> 'Активні теми',
  'FEED_TOPICS_NEW'			=> 'Нові теми',
	'RULES_ATTACH_CAN'	=> 'Ви <strong>можете</strong> додавати файли у цьому форумі',
	'RULES_ATTACH_CANNOT'	=> 'Ви <strong>не можете</strong> додавати файли у цьому форумі',
	'RULES_DELETE_CAN'	=> 'Ви <strong>можете</strong> видаляти ваші повідомлення у цьому форумі',
	'RULES_DELETE_CANNOT'	=> 'Ви <strong>не можете</strong> видаляти ваші повідомлення у цьому форумі',
	'RULES_DOWNLOAD_CAN'	=> 'Ви <strong>можете</strong> завантажувати файли у цьому форумі',
	'RULES_DOWNLOAD_CANNOT'	=> 'Ви <strong>не можете</strong> завантажувати файли у цьому форумі',
	'RULES_EDIT_CAN'	=> 'Ви <strong>можете</strong> редагувати ваші повідомлення у цьому форумі',
	'RULES_EDIT_CANNOT'	=> 'Ви <strong>не можете</strong> редагувати ваші повідомлення у цьому форумі',
	'RULES_LOCK_CAN'	=> 'Ви <strong>можете</strong> закривати свої теми у цьому форумі',
	'RULES_LOCK_CANNOT'	=> 'Ви <strong>не можете</strong> закривати свої теми у цьому форумі',
	'RULES_POST_CAN'	=> 'Ви <strong>можете</strong> створювати нові теми у цьому форумі',
	'RULES_POST_CANNOT'	=> 'Ви <strong>не можете</strong> створювати нові теми у цьому форумі',
	'RULES_REPLY_CAN'	=> 'Ви <strong>можете</strong> відповідати на теми у цьому форумі',
	'RULES_REPLY_CANNOT'	=> 'Ви <strong>не можете</strong> відповідати на теми у цьому форумі',
	'RULES_VOTE_CAN'	=> 'Ви <strong>можете</strong> голосувати у цьому форумі',
	'RULES_VOTE_CANNOT'	=> 'Ви <strong>не можете</strong> голосувати у цьому форумі',
	'SEARCH'	=> 'Пошук',
	'SEARCH_MINI'	=> 'Пошук...',
	'SEARCH_ADV'	=> 'Розширений пошук',
	'SEARCH_ADV_EXPLAIN'	=> 'Налаштування розширеного пошуку',
	'SEARCH_KEYWORDS'	=> 'Пошук за ключовими словами',
	'SEARCHING_FORUMS'	=> 'Пошук в форумах',
	'SEARCH_ACTIVE_TOPICS'	=> 'Активні теми',
	'SEARCH_FOR'	=> 'Знайти',
	'SEARCH_FORUM'	=> 'Шукати у цьому форумі',
	'SEARCH_NEW'	=> 'Нові повідомлення',
	'SEARCH_POSTS_BY'	=> 'Шукати повідомлення',
	'SEARCH_SELF'	=> 'Ваші повідомлення',
	'SEARCH_TOPIC'	=> 'Пошук в темі',
	'SEARCH_UNANSWERED'	=> 'Теми без відповідей',
  'SEARCH_UNREAD' => 'Непрочитані повідомлення',
  'SEARCH_USER_POSTS'			=> 'Знайти повідомлення користувача',
	'SECONDS'	=> 'Секунд',
	'SELECT'	=> 'Вибрати',
	'SELECT_ALL_CODE'	=> 'Виділити все',
	'SELECT_DESTINATION_FORUM'	=> 'Виберіть форум призначення',
	'SELECT_FORUM'	=> 'Оберіть форум',
	'SEND_EMAIL'	=> 'E-mail', // Used for submit buttons
	'SEND_PRIVATE_MESSAGE'	=> 'Відправити приватне повідомлення',
	'SETTINGS'	=> 'Налаштування',
	'SIGNATURE'	=> 'Підпис',
	'SKIP'	=> 'Пропустити',
	'SMTP_NO_AUTH_SUPPORT'	=> 'SMTP сервер не підтримує автентифікацію',
	'SORRY_AUTH_READ'	=> 'Ви не авторизовані щоб читати цей форум',
	'SORRY_AUTH_VIEW_ATTACH'	=> 'Ви не авторизовані, щоб завантажити цей файл',
	'SORT_BY'	=> 'Сортувати за',
	'SORT_JOINED'	=> 'З нами з',
	'SORT_LOCATION'	=> 'Звідки',
	'SORT_RANK'	=> 'Статус',
  'SORT_POSTS' => 'Повідомлення',
	'SORT_TOPIC_TITLE'	=> 'Назва теми',
	'SORT_USERNAME'	=> 'Ім\'я користувача',
	'SPLIT_TOPIC'	=> 'Розділити тему',
	'SQL_ERROR_OCCURRED'	=> 'Виникла помилка SQL під час завантаження цієї сторінки. Будь-ласка повідомте %sадміністратора%s, якщо помилка буде повторюватись.',
	'STATISTICS'	=> 'Статистика',
	'START_WATCHING_FORUM'	=> 'Підписатись на цей форум',
	'START_WATCHING_TOPIC'	=> 'Підписатись на цю тему',
	'STOP_WATCHING_FORUM'	=> 'Відписатись від цього форуму',
	'STOP_WATCHING_TOPIC'	=> 'Відписатись від цієї теми',
	'SUBFORUM'	=> 'Підфорум',
	'SUBFORUMS'	=> 'Підфоруми',
	'SUBJECT'	=> 'Тема',
	'SUBMIT'	=> 'Відіслати',
	'TERMS_USE'	=> 'Правила використання',
	'TEST_CONNECTION'	=> 'Перевірити з\'єднання',
	'THE_TEAM'	=> 'Команда',
	'TIME'	=> 'Час',
  'TOO_LARGE'                  => 'Значення, яке ви ввели є занадто великим.',
	'TOO_LARGE_MAX_RECIPIENTS'      => 'Введене вами значення налаштування <strong>Максимально дозволена кількість одержувачів приватного повідомлення</strong> є занадто великим.',
	'TOO_LONG'                  => 'Введене вами значення занадто довге.',
	'TOO_LONG_AIM'	=> 'Введене вами ім\'я AIM надто довге.',
	'TOO_LONG_CONFIRM_CODE'	=> 'Введений вами код підтвердження надто довгий.',
	'TOO_LONG_ICQ'	=> 'Введений вами номер ICQ надто довгий.',
	'TOO_LONG_INTERESTS'	=> 'Введена вами інформація про інтереси надто довга.',
	'TOO_LONG_JABBER'	=> 'Введене вами ім\'я облікового запису jabber надто довге.',
	'TOO_LONG_LOCATION'	=> 'Введена вами інформація "Звідки" надто довга.',
	'TOO_LONG_MSN'	=> 'Введена вами ім\'я MSN надто довге.',
	'TOO_LONG_NEW_PASSWORD'	=> 'Введений вами пароль надто довгий.',
	'TOO_LONG_OCCUPATION'	=> 'Введена вами інформація про рід занять надто довга.',
	'TOO_LONG_PASSWORD_CONFIRM'	=> 'Введене вами підтвердження паролю надто довге.',
	'TOO_LONG_USER_PASSWORD'	=> 'Введений вами пароль надто довгий.',
	'TOO_LONG_USERNAME'	=> 'Введене вами ім\'я користувача надто довге.',
	'TOO_LONG_EMAIL'	=> 'Введена вами адреса e-mail надто довга.',
	'TOO_LONG_EMAIL_CONFIRM'	=> 'Введене вами підтвердження адреси e-mail надто довге.',
	'TOO_LONG_WEBSITE'	=> 'Введена вами адреса вебсайту надто довга.',
	'TOO_LONG_YIM'	=> 'Введене вами ім\'я Yahoo Messenger надто довге.',
	'TOO_SMALL'                  => 'Значення, яке ви ввели є занадто малим.',
  'TOO_SMALL_MAX_RECIPIENTS'      => 'Введене вами значення налаштування <strong>Максимально дозволена кількість одержувачів приватного повідомлення</strong> є занадто малим.',
	'TOO_MANY_VOTE_OPTIONS'	=> 'Ви вибрали надто багато варіантів при голосуванні.',
	'TOO_SHORT'                  => 'Введене вами значення занадто коротке.',
	'TOO_SHORT_AIM'	=> 'Введене вами ім\'я AIM надто коротке.',
	'TOO_SHORT_CONFIRM_CODE'	=> 'Введений вами код підтвердження надто короткий.',
	'TOO_SHORT_ICQ'	=> 'Введений вами номер ICQ надто короткий.',
	'TOO_SHORT_INTERESTS'	=> 'Введена вами інформація про інтереси надто коротка.',
	'TOO_SHORT_JABBER'	=> 'Введене вами ім\'я облікового запису jabber надто коротке.',
	'TOO_SHORT_LOCATION'	=> 'Введена вами інформація "Звідки" надто коротка.',
	'TOO_SHORT_MSN'	=> 'Введена вами ім\'я MSN надто коротке.',
	'TOO_SHORT_NEW_PASSWORD'	=> 'Введений вами пароль надто короткий.',
	'TOO_SHORT_OCCUPATION'	=> 'Введена вами інформація про рід занять надто коротка.',
	'TOO_SHORT_PASSWORD_CONFIRM'	=> 'Введене вами підтвердження паролю надто коротке.',
	'TOO_SHORT_USER_PASSWORD'	=> 'Введений вами пароль надто короткий.',
	'TOO_SHORT_USERNAME'	=> 'Введене вами ім\'я користувача надто коротке.',
	'TOO_SHORT_EMAIL'	=> 'Введена вами адреса e-mail надто коротка.',
	'TOO_SHORT_EMAIL_CONFIRM'	=> 'Введене вами підтвердження адреси e-mail надто коротке.',
	'TOO_SHORT_WEBSITE'	=> 'Введена вами адреса вебсайту надто коротка.',
	'TOO_SHORT_YIM'	=> 'Введене вами ім\'я Yahoo Messenger надто коротке.',
	'TOPIC'	=> 'Тема',
	'TOPICS'	=> 'Теми',
	'TOPICS_UNAPPROVED' => 'Принаймні одну тему в цьому форумі не було схвалено.',
	'TOPIC_ICON'	=> 'Значок теми',
	'TOPIC_LOCKED'	=> 'Ця тема закрита, ви не можете редагувати повідомлення і писати відповіді',
	'TOPIC_LOCKED_SHORT' => 'Тему закрито',
	'TOPIC_MOVED'	=> 'Переміщено',
	'TOPIC_REVIEW'	=> 'Огляд теми',
	'TOPIC_TITLE'	=> 'Назва теми',
	'TOPIC_UNAPPROVED'	=> 'Дану тему не було схвалено',
	'TOTAL_ATTACHMENTS'	=> 'Приєднаний(і) файл(и)',
	'TOTAL_LOG'	=> '1 лог',
	'TOTAL_LOGS'	=> '%d логів',
	'TOTAL_NO_PM'	=> 'Всього 0 приватних повідомлень',
	'TOTAL_PM'	=> 'Всього 1 приватне повідомлення',
	'TOTAL_PMS'	=> 'Всього %d приватних повідомлень',
	'TOTAL_POSTS'	=> 'Всього повідомлень:',
	'TOTAL_POSTS_OTHER'	=> 'Всього повідомлень: <strong>%d</strong>',
	'TOTAL_POSTS_ZERO'	=> 'Всього повідомлень: <strong>0</strong>',
	'TOPIC_REPORTED'	=> 'На цю тему надійшли скарги',
	'TOTAL_TOPICS_OTHER'	=> 'Всього тем: <strong>%d</strong>',
	'TOTAL_TOPICS_ZERO'	=> 'Всього тем: <strong>0</strong>',
	'TOTAL_USERS_OTHER'	=> 'Всього учасників: <strong>%d</strong>',
	'TOTAL_USERS_ZERO'	=> 'Всього учасників: <strong>0</strong>',
	'TRACKED_PHP_ERROR'	=> 'Відстежено помилок PHP: %s',
	'UNABLE_GET_IMAGE_SIZE'	=> 'Неможливо визначити розміри зображення.',
	'UNABLE_TO_DELIVER_FILE'	=> 'Неможливо доставити файл.',
	'UNKNOWN_BROWSER'	=> 'Невідомий браузер',
	'UNMARK_ALL'	=> 'Зняти відмітки',
	'UNREAD_MESSAGES'	=> 'Непрочитані повідомлення',
	'UNREAD_PM'	=> '<strong>%d</strong> непрочитане повідомлення',
	'UNREAD_PMS'	=> '<strong>%d</strong> непрочитаних повідомлень',
	'UNREAD_POST'         => 'Непрочитане повідомлення',
	'UNREAD_POSTS'         => 'Непрочитані повідомлення',
	'UNWATCH_FORUM_CONFIRM'		=> 'Ви впевнені, що бажаєте відписатись від цього форуму?',
	'UNWATCH_FORUM_DETAILED'	=> 'Ви впевнені, що бажаєте відписатись від форуму “%s”?',
	'UNWATCH_TOPIC_CONFIRM'		=> 'Ви впевнені, що бажаєте відписатись від цієї теми?',
	'UNWATCH_TOPIC_DETAILED'	=> 'Ви впевнені, що бажаєте відписатись від теми “%s”?',
  'UNWATCHED_FORUMS'	=> 'Відтепер ви не слідкуєте за вибраними форумами.',
	'UNWATCHED_TOPICS'	=> 'Відтепер ви не слідкуєте за вибраними темами.',
	'UPDATE'	=> 'Оновити',
	'UPLOAD_IN_PROGRESS'	=> 'Відбувається завантаження.',
	'URL_REDIRECT'	=> 'Якщо ваш браузер не підтримує автоматичний перехід, будь-ласка, %sнатисніть сюди%s для переходу.',
	'USERGROUPS'	=> 'Групи',
	'USERNAME'	=> 'Ім\'я користувача',
	'USERNAMES'	=> 'Імена користувачів',
	'USER_AVATAR'	=> 'Аватар користувача',
	'USER_CANNOT_READ'	=> 'Ви не можете читати повідомлення у цьому форумі',
	'USER_POST'	=> '%d повідомлення',
	'USER_POSTS'	=> '%d повідомлень',
	'USERS'	=> 'Користувачі',
	'USE_PERMISSIONS'	=> 'Перевірити права користувачів.',
	'USER_NEW_PERMISSION_DISALLOWED' => 'Вам не дозволено використовувати цю можливість. Можливо, ви недавно зареєструвались на форумі, або вам необхідно проявити більше активності, щоб отримати можливість її використання.',
	'VARIANT_DATE_SEPARATOR'	=> ' / ',
	'VIEWED'	=> 'Переглянуто',
	'VIEWING_FAQ'	=> 'Переглядає FAQ',
	'VIEWING_MEMBERS'	=> 'Переглядає список учасників',
	'VIEWING_ONLINE'	=> 'Переглядає хто зараз онлайн',
	'VIEWING_MCP'	=> 'Переглядає панель модератора',
	'VIEWING_MEMBER_PROFILE'	=> 'Переглядає профіль користувача',
	'VIEWING_PRIVATE_MESSAGES'	=> 'Переглядає приватне повідомлення',
	'VIEWING_UCP'	=> 'Переглядає панель керування',
	'VIEWING_REGISTER'	=> 'Реєструє обліковий запис',
	'VIEWS'	=> 'Перегляди',
	'VIEW_BOOKMARKS'	=> 'Переглянути закладки',
	'VIEW_FORUM_LOGS'	=> 'Переглянути логи',
	'VIEW_LATEST_POST'	=> 'Переглянути останнє повідомлення',
	'VIEW_NEWEST_POST'	=> 'Переглянути перше непрочитане повідомлення',
	'VIEW_NOTES'	=> 'Переглянути нотатки користувача',
	'VIEW_ONLINE_TIME'	=> 'Ця інформація базується на активності користувачів впродовж останньої %d хвилини',
	'VIEW_ONLINE_TIMES'	=> 'Ця інформація базується на активності користувачів впродовж останніх %d хвилин',
	'VIEW_TOPIC'	=> 'Перегляд теми',
	'VIEW_TOPIC_ANNOUNCEMENT'	=> 'Оголошення: ',
	'VIEW_TOPIC_GLOBAL'	=> 'Загальне оголошення: ',
	'VIEW_TOPIC_LOCKED'	=> 'Закрито: ',
	'VIEW_TOPIC_LOGS'	=> 'Переглянути логи',
	'VIEW_TOPIC_MOVED'	=> 'Переміщено: ',
	'VIEW_TOPIC_POLL'	=> 'Опитування: ',
	'VIEW_TOPIC_STICKY'	=> 'Прикріплена: ',
	'VISIT_WEBSITE'	=> 'Відвідати вебсайт',
	'WARNINGS'	=> 'Попередження',
	'WARN_USER'	=> 'Зробити попередження',
  'WATCH_FORUM_CONFIRM'	=> 'Ви впевнені, що бажаєте підписатись на цей форум?',
	'WATCH_FORUM_DETAILED'	=> 'Ви впевнені, що бажаєте підписатись на форум “%s”?',
	'WATCH_TOPIC_CONFIRM'	=> 'Ви впевнені, що бажаєте підписатись на цю тему?',
	'WATCH_TOPIC_DETAILED'	=> 'Ви впевнені, що бажаєте підписатись на тему “%s”?',
	'WELCOME_SUBJECT'	=> 'Ласкаво просимо на %s форум',
	'WEBSITE'	=> 'Вебсайт',
	'WHOIS'	=> 'Whois',
	'WHO_IS_ONLINE'	=> 'Хто зараз онлайн',
	'WRONG_PASSWORD'	=> 'Ви ввели невірний пароль.',
	'WRONG_DATA_ICQ'	=> 'Введений вами номер не є правильним номером icq.',
	'WRONG_DATA_JABBER'	=> 'Введене вами ім\'я не є правильним обліковим записом jabber.',
	'WRONG_DATA_LANG'	=> 'Вказано неправильну мову.',
	'WRONG_DATA_WEBSITE'	=> 'Адреса вебсайту має бути правильним посиланням на сайт, включаючи назву протоколу. Наприклад http://www.example.com/.',
	'WROTE'	=> 'написав',
	'YEAR'	=> 'Рік',
	'YEAR_MONTH_DAY'	=> '(РРРР-ММ-ДД)',
	'YES'	=> 'Так',
	'YIM'	=> 'YIM',
	'YOU_LAST_VISIT'	=> 'Ваш останній візит: %s',
	'YOU_NEW_PM'	=> 'Нове приватне повідомлення чекає на вас в папці Вхідні.',
	'YOU_NEW_PMS'	=> 'Нові приватні повідомлення чекають на вас в папці Вхідні.',
	'YOU_NO_NEW_PM'	=> 'Немає нових приватних повідомлень.',
	'TOO_LONG_DATEFORMAT'	=> 'Введений вами формат дати занадто довгий.',
	'TOO_SHORT_DATEFORMAT'	=> 'Введений вами формат дати надто короткий.',
	'UNWATCHED_FORUMS_TOPICS'	=> 'Ви відписались від обраних тем.',
	'MERGE_POSTS'	=> 'Перемістити повідомлення',
   
	'NEXT_STEP'	=> 'Далі',
	'POST_TOPIC'	=> 'Створити нову тему',
	'PREVIOUS_STEP'	=> 'Назад',
	'READING_LINK'	=> 'Переглядає  %s',
	'SEND_EMAIL_USER'	=> 'Надіслати е-mail користувачу',

	'datetime'	=> array(
	'TODAY'	=> 'Сьогодні',
	'TOMORROW'	=> 'Завтра',
	'YESTERDAY'	=> 'Вчора',
	'AGO'		=> array(
			0		=> 'менше хвилини тому',
			1		=> '%d хвилини тому',
			2		=> '%d хвилин тому',
			60		=> '1 годину тому',
		),
		'Sunday'	=> 'неділя',
		'Monday'	=> 'понеділок',
		'Tuesday'	=> 'вівторок',
		'Wednesday'	=> 'середа',
		'Thursday'	=> 'четвер',
		'Friday'	=> 'п\'ятниця',
		'Saturday'	=> 'субота',
		'Sun'	=> 'Нед',
		'Mon'	=> 'Пон',
		'Tue'	=> 'Вів',
		'Wed'	=> 'Сер',
		'Thu'	=> 'Чет',
		'Fri'	=> 'П\'ят',
		'Sat'	=> 'Суб',
		'January'	=> 'Січня',
		'February'	=> 'Лютого',
		'March'	=> 'Березня',
		'April'	=> 'Квітня',
		'May'	=> 'Травня',
		'June'	=> 'Червня',
		'July'	=> 'Липня',
		'August'	=> 'Серпня',
		'September'	=> 'Вересня',
		'October'	=> 'Жовтня',
		'November'	=> 'Листопада',
		'December'	=> 'Грудня',
		'Jan'	=> 'січня',
		'Feb'	=> 'лютого',
		'Mar'	=> 'березня',
		'Apr'	=> 'квітня',
		'May_short'	=> 'травня',
		'Jun'	=> 'червня',
		'Jul'	=> 'липня',
		'Aug'	=> 'серпня',
		'Sep'	=> 'вересня',
		'Oct'	=> 'жовтня',
		'Nov'	=> 'листопада',
		'Dec'	=> 'грудня',
	),

	'tz'	=> array(
		'-12'	=> 'UTC - 12 годин',
		'-11'	=> 'UTC - 11 годин',
		'-10'	=> 'UTC - 10 годин',
		'-9.5'	=> 'UTC - 9:30 годин',
		'-9'	=> 'UTC - 9 годин',
		'-8'	=> 'UTC - 8 годин',
		'-7'	=> 'UTC - 7 годин',
		'-6'	=> 'UTC - 6 годин',
		'-5'	=> 'UTC - 5 годин',
	        '-4.5'  => 'UTC - 4:30 годин',
		'-4'	=> 'UTC - 4 годин',
		'-3.5'	=> 'UTC - 3:30 годин',
		'-3'	=> 'UTC - 3 годин',
		'-2'	=> 'UTC - 2 годин',
		'-1'	=> 'UTC - 1 година',
		'0'	=> 'UTC',
		'1'	=> 'UTC + 1 година',
		'2'	=> 'UTC + 2 годин',
		'3'	=> 'UTC + 3 годин',
		'3.5'	=> 'UTC + 3:30 годин',
		'4'	=> 'UTC + 4 годин',
		'4.5'	=> 'UTC + 4:30 годин',
		'5'	=> 'UTC + 5 годин',
		'5.5'	=> 'UTC + 5:30 годин',
		'5.75'	=> 'UTC + 5:45 годин',
		'6'	=> 'UTC + 6 годин',
		'6.5'	=> 'UTC + 6:30 годин',
		'7'	=> 'UTC + 7 годин',
		'8'	=> 'UTC + 8 годин',
		'8.75'	=> 'UTC + 8:45 годин',
		'9'	=> 'UTC + 9 годин',
		'9.5'	=> 'UTC + 9:30 годин',
		'10'	=> 'UTC + 10 годин',
		'10.5'	=> 'UTC + 10:30 годин',
		'11'	=> 'UTC + 11 годин',
		'11.5'	=> 'UTC + 11:30 годин',
		'12'	=> 'UTC + 12 годин',
		'12.75'	=> 'UTC + 12:45 годин',
		'13'	=> 'UTC + 13 годин',
		'14'	=> 'UTC + 14 годин',
		'dst'	=> '[ <abbr title="Daylight Saving Time">DST</abbr> ]',
	),

	'tz_zones'	=> array(
		'-12'	=> '[UTC - 12] Меридіан зміни дат (захід)',
		'-11'	=> '[UTC - 11] о. Мідвей, Самоа',
		'-10'	=> '[UTC - 10] Гаваї',
		'-9.5'	=> '[UTC - 9:30] Маркізькі острови',
		'-9'	=> '[UTC - 9] Аляска',
		'-8'	=> '[UTC - 8] Тихоокеанський час (США и Канада) і Тихуана',
		'-7'	=> '[UTC - 7] Арізона',
		'-6'	=> '[UTC - 6] Мехіко, Центральна Америка, Центральний час (США та Канада)',
		'-5'	=> '[UTC - 5] Індіана (схід), Східний час (США та Канада)',
	        '-4.5'  => '[UTC - 4:30] Венесуела',
		'-4'	=> '[UTC - 4] Каракас, Сантьяго, Атлантичний час (Канада)',
		'-3.5'	=> '[UTC - 3:30] Ньюфаундленд',
		'-3'	=> '[UTC - 3] Бразилія, Гренландія',
		'-2'	=> '[UTC - 2] Середньоатлантичний час',
		'-1'	=> '[UTC - 1] Азорскі острови, острови Зеленого мису',
		'0'	=> '[UTC] Час за Грінвічем: Дублін, Лондон, Лісабон, Едінбург',
		'1'	=> '[UTC + 1] Берлін, Мадрид, Париж, Рим, Західна Центральна Африка',
		'2'	=> '[UTC + 2] Афіни, Вільнюс, Київ, Мінськ, Рига, Талін, Центральна Африка',
		'3'	=> '[UTC + 3] Волгоград, Москва, Санкт-Петербург',
		'3.5'	=> '[UTC + 3:30] Тегеран',
		'4'	=> '[UTC + 4] Баку, Єреван, Самара, Тбілісі',
		'4.5'	=> '[UTC + 4:30] Кабул',
		'5'	=> '[UTC + 5] Єкатєрінбург, Ісламабад, Карачі, Оренбург, Ташкент',
		'5.5'	=> '[UTC + 5:30] Бомбей, Калькутта, Мадрас, Нью-Делі',
		'5.75'	=> '[UTC + 5:45] Катманду',
		'6'	=> '[UTC + 6] Алмати, Астана, Новосибірськ, Омск',
		'6.5'	=> '[UTC + 6:30] Рангун',
		'7'	=> '[UTC + 7] Бангкок, Красноярськ',
		'8'	=> '[UTC + 8] Гонконг, Іркутськ, Пекін, Сингапур',
		'8.75'	=> '[UTC + 8:45] Південно-східна Західна Австралія',
		'9'	=> '[UTC + 9] Токіо, Сеул, Чіта, Якутськ',
		'9.5'	=> '[UTC + 9:30] Дарвін',
		'10'	=> '[UTC + 10] Владівосток, Канберра, Мельбурн, Сідней',
		'10.5'	=> '[UTC + 10:30] Лорд-Хау',
		'11'	=> '[UTC + 11] Магадан, Сахалін, Соломонові острови',
		'11.5'	=> '[UTC + 11:30] Острів Норфолк',
		'12'	=> '[UTC + 12] Камчатка, Нова Зеландія, Фіджі',
		'12.75'	=> '[UTC + 12:45] Острови Чатем',
		'13'	=> '[UTC + 13] Острови Фенікс, Тонга',
		'14'	=> '[UTC + 14] Острів Лайн',
	),

	// The value is only an example and will get replaced by the current time on view
	'dateformats'	=> array(
		'd M Y, H:i'	=> '01 січня 2007, 13:37',
		'd M Y H:i'	=> '01 січня 2007 13:37',
		'M jS, \'y, H:i'	=> 'Січня 1, \'07, 13:37',
		'D M d, Y g:i a'	=> 'Пон Січня 01, 2007 1:37 pm',
		'F jS, Y, g:i a'	=> 'Січня 1, 2007, 1:37 pm',
		'|d M Y|, H:i'	=> 'Сьогодні, 13:37 / 01 січня 2007, 13:37',
		'|F jS, Y|, g:i a'	=> 'Сьогодні, 1:37 pm / Січня 1, 2007, 1:37 pm',
	),

	// The default dateformat which will be used on new installs in this language
	// Translators should change this if a the usual date format is different
	'default_dateformat'	=> 'D M d, Y g:i a', // Mon Jan 01, 2007 1:37 pm

));

?>